@@ -182,6 +182,7 @@ int written;
 interface_description_block_t *idbhdr;
 total_length_t *totallength;
 char vendor[6];
+char tr[1];
 uint8_t idb[1024];
 
 memset(&idb, 0, 256);
@@ -195,6 +196,8 @@ idblen += addoption(idb +idblen, IF_NAME, strlen(interfacestr), interfacestr);
 memset(&vendor, 0, 6);
 memcpy(&vendor, macorig, 3);
 idblen += addoption(idb +idblen, IF_MACADDR, 6, vendor);
+tr[0] = TSRESOL_USEC;
+idblen += addoption(idb +idblen, IF_TSRESOL, 1, tr);
 idblen += addoption(idb +idblen, SHB_EOC, 0, NULL);
 
 totallength = (total_length_t*)(idb +idblen);
@@ -240,7 +243,7 @@ if(uname(&unameData) == 0)
 	shblen += addoption(shb +shblen, SHB_HARDWARE, strlen(unameData.machine), unameData.machine);
 	sprintf(sysinfo, "%s %s", unameData.sysname, unameData.release);
 	shblen += addoption(shb +shblen, SHB_OS, strlen(sysinfo), sysinfo);
-	sprintf(sysinfo, "hcxdumptool %s", VERSION);
+	sprintf(sysinfo, "hcxdumptool %s", VERSION_TAG);
 	shblen += addoption(shb +shblen, SHB_USER_APPL, strlen(sysinfo), sysinfo);
 	}
 
